@@ -32,6 +32,8 @@
    /* probably want this defined too, unless your bot is a proxy file */
    /* server.)  leaving out the file system shaves about 45k from the */
    /* executable on my linux system. */
+   /* it's pretty dumb to #define this if you have modules, since the */
+   /* module code removes more of the file system than the NO_FILE_SYS*/
 #undef NO_FILE_SYSTEM
 
    /* if you want the bot to die when it receives the TERM or HUP */
@@ -46,11 +48,11 @@
 
    /* enable the 'tcl' and 'set' command (let owners */
    /* directly execute Tcl commands)? */
-#undef ENABLE_TCL
+#define ENABLE_TCL
 
    /* add the 'simul' command (masters can manipulate other people on */
    /* the party line)? saves about 610 bytes :) */
-#undef ENABLE_SIMUL
+#define ENABLE_SIMUL
 
    /* add the 'dccsimul' tcl command (needed by certain scripts like */
    /* action.fix.tcl) */
@@ -65,7 +67,7 @@
 #define REMOTE_BOOTS
 
    /* restrict remote boots to share-bots only?  (REMOTE_BOOTS must be on) */
-#undef SHAREBOT_BOOTS
+#define SHAREBOT_BOOTS
 
    /* when sharing user lists, ignore +n modes from other bots?  this will */
    /* only work if you are NON-PASSIVE  (ie, only the master bot is able to */
@@ -81,7 +83,7 @@
    /* This enables the 'raw' binding for TCL scripts it takes a bit more */
    /* CPU than a regular binding because it checks everything from the   */
    /* server      */
-#define RAW_BINDS
+#undef RAW_BINDS
 
    /* squelch the error message when rejecting a dcc chat or send? */
    /* (normally it says something silly.  but sometimes irc opers detect */
@@ -125,6 +127,9 @@
   /* define this if you want to bounce all server bans */
 #define BOUNCE_SERVER_BANS
 
+  /* define if you have a Cisco PIX firewall */
+#undef HAVE_NAT
+
 /***********************************************************************/
 /***** the 'configure' script should make this next part automatic *****/
 /***********************************************************************/
@@ -136,7 +141,7 @@
 
 /* useless with no irc */
 #ifdef NO_IRC
-#define NO_FILE_SYSTEM
+/* #define NO_FILE_SYSTEM <- this *is* usefull with no_irc */
 #undef USE_CONSOLE_R
 #undef CHECK_STONED
 #undef BOUNCE_SERVER_BANS
@@ -159,6 +164,14 @@
 #include <unistd.h>
 #endif
 
+#if defined(MODULES) && !defined(MODULES_OK)
+#include "you/can't/compile/with/module/support/on/this/system"
+#endif
+
+#if defined(MODULES) && defined(NO_FILE_SYSTEM)
+#include "listen_doofus_I_said_it_was_pointless_to_do_modules_and_NO_FILE_SYSTEM"
+#endif
+
 /* almost every module needs some sort of time thingy, so... */
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -283,7 +296,7 @@ struct dcc_t {
   void *user;            /* really struct userrec but SHHH!! */
   char nick[NICKLEN];
   char host[UHOSTLEN];
-  unsigned char type;
+  unsigned int type;
   union {
     struct chat_info *chat;
     struct file_info *file;
@@ -364,7 +377,7 @@ struct xfer_info {
   unsigned long length;
   unsigned long sent;
   unsigned long acked;
-  char buf[121];            /* temporary storage for byte counts */
+  char buf[4];              /* you only need 5 bytes! */
   unsigned char sofar;      /* how much of the byte count received */
   time_t pending;           /* used to expire stale file offerings */
   char from[NICKLEN];       /* [GET] user who offered the file */
@@ -378,6 +391,7 @@ struct bot_info {
   time_t timer;
   char version[121];        /* channel/version info */
   char linker[21];          /* who requested this link */
+  int numver;
 };
 
 #define DCC_RELAY       12  /* relayed connection to a bot */
@@ -434,7 +448,8 @@ struct script_info {
 #define STRIP_BOLD   2      /* remove bold codes */
 #define STRIP_REV    4      /* remove reverse video codes */
 #define STRIP_UNDER  8      /* remove underline codes */
-#define STRIP_ALL    15     /* remove every damn thing! */
+#define STRIP_ANSI   16     /* remove ALL ansi codes */
+#define STRIP_ALL    31     /* remove every damn thing! */
 
 /* for dcc bot links: */
 #define STAT_PINGED  0x01   /* waiting for ping to return */
@@ -448,7 +463,7 @@ struct script_info {
 
 /* bug: changing the order of these will mess up filedb */
 #define USER_GLOBAL   0x00000001  /* o   user is +o on all channels */
-#define USER_DEOP     0x00800002  /* d   user is global de-op */
+#define USER_DEOP     0x00000002  /* d   user is global de-op */
 #define USER_KICK     0x00000004  /* k   user is global auto-kick */
 #define USER_FRIEND   0x00000008  /* f   user is global friend*/
 #define USER_MASTER   0x00000010  /* m   user has full bot access */
@@ -578,9 +593,11 @@ typedef struct {
 #define SOCK_NONSOCK    0x10    /* used for file i/o on debug */
 #define SOCK_STRONGCONN 0x20    /* don't report success until sure */
 
-/* fake idx's for dprintf */
-#define DP_STDOUT       -1
-#define DP_LOG          -2
+/* fake idx's for dprintf - these should be rediculously large +ve nums */
+#define DP_STDOUT       0x7FF1
+#define DP_LOG          0x7FF2
+#define DP_SERVER       0x7FF3
+#define DP_HELP         0x7FF4
 
 #define NORMAL          0
 #define QUICK           1
@@ -593,4 +610,13 @@ typedef struct {
 #define NOTE_TCL        4   /* tcl binding caught it */
 #define NOTE_AWAY       5   /* away; stored */
 
+/* builtins values for add_builins */
+#define BUILTIN_DCC   1
+#define BUILTIN_MSG   2
+#define BUILTIN_FILES 3
+#define STR_PROTECT  2
+#define STR_DIR      1
+
+/* it's used in so many places, let's put it here */
+typedef int (*Function)();
 #endif
